# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Step(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'step_type': 'StepType',
        'step_id': 'str',
        'args': 'list[str]'
    }

    attribute_map = {
        'step_type': 'step_type',
        'step_id': 'step_id',
        'args': 'args'
    }

    def __init__(self, step_type=None, step_id=None, args=None):  # noqa: E501
        """Step - a model defined in Swagger"""  # noqa: E501

        self._step_type = None
        self._step_id = None
        self._args = None
        self.discriminator = None

        if step_type is not None:
            self.step_type = step_type
        if step_id is not None:
            self.step_id = step_id
        if args is not None:
            self.args = args

    @property
    def step_type(self):
        """Gets the step_type of this Step.  # noqa: E501


        :return: The step_type of this Step.  # noqa: E501
        :rtype: StepType
        """
        return self._step_type

    @step_type.setter
    def step_type(self, step_type):
        """Sets the step_type of this Step.


        :param step_type: The step_type of this Step.  # noqa: E501
        :type: StepType
        """

        self._step_type = step_type

    @property
    def step_id(self):
        """Gets the step_id of this Step.  # noqa: E501


        :return: The step_id of this Step.  # noqa: E501
        :rtype: str
        """
        return self._step_id

    @step_id.setter
    def step_id(self, step_id):
        """Sets the step_id of this Step.


        :param step_id: The step_id of this Step.  # noqa: E501
        :type: str
        """

        self._step_id = step_id

    @property
    def args(self):
        """Gets the args of this Step.  # noqa: E501


        :return: The args of this Step.  # noqa: E501
        :rtype: list[str]
        """
        return self._args

    @args.setter
    def args(self, args):
        """Sets the args of this Step.


        :param args: The args of this Step.  # noqa: E501
        :type: list[str]
        """

        self._args = args

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Step, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Step):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
